import { fileURLToPath, URL } from 'node:url';
import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
const path = require('path');
const common = path.resolve(__dirname, '../common');
export default defineConfig(({ mode }) => {
  const env = loadEnv(mode, __dirname);
  return {
    // 静态路径
    base: env.VITE_BASE_URL,
    // 打包名称
    build: {
      outDir: env.VITE_OUT_DIR,
    },
    plugins: [vue()],
    server: {
      port: 8005,
      proxy: {
        '/files': {
          target: 'http://basic.waityou24.cn',
        },
        '/jcyjdtglpt/v1/api': {
          target: 'http://192.168.1.113:13010',
          changeOrigin: true,
          ws: false,
        },
        '/semail/api': {
          target: 'http://basic.waityou24.cn',
          changeOrigin: true,
          ws: false,
        },
        '/studioadmin/api': {
          target: 'http://192.168.1.113:16002',
          changeOrigin: true,
          ws: false,
        },
      },
      fs: {
        strict: false,
      },
    },
    resolve: {
      alias: {
        '@': fileURLToPath(new URL('./src', import.meta.url)),
        '@common': common,
      },
    },
    css: {
      preprocessorOptions: {
        scss: {
          additionalData: `@import "@/assets/style/mixin.scss";`, // 此处全局的scss文件
        },
      },
    },
  };
});
